@@ -36,7 +36,6 @@ except ImportError:
 
 import matplotlib
 import lems.model.model as lems_model
-from lems.model.fundamental import Include
 from lems.parser.LEMS import LEMSFileParser
 
 from pyneuroml import __version__
@@ -59,7 +58,9 @@ lems_model_with_units = None
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
-version_string = "pyNeuroML v{} (libNeuroML v{}, jNeuroML v{})".format(__version__, neuroml.__version__, JNEUROML_VERSION)
+version_string = "pyNeuroML v{} (libNeuroML v{}, jNeuroML v{})".format(
+    __version__, neuroml.__version__, JNEUROML_VERSION
+)
 
 
 def parse_arguments():
@@ -83,11 +84,7 @@ def parse_arguments():
         formatter_class=argparse.RawTextHelpFormatter,
     )
 
-    parser.add_argument(
-        "-version",
-        help="Print version and exit",
-        action="store_true"
-    )
+    parser.add_argument("-version", help="Print version and exit", action="store_true")
 
     shared_options = parser.add_argument_group(
         title="Shared options",
@@ -231,6 +228,12 @@ def parse_arguments():
         action="store_true",
         help=("(Via jNeuroML) Load a LEMS file, and convert it\n" "to Brian2 format"),
     )
+    # TODO: add run_lems_with_jneuroml_moose API function
+    mut_exc_opts.add_argument(
+        "-moose",
+        action="store_true",
+        help=("(Via jNeuroML) Load a LEMS file, and convert it\n" "to Moose format"),
+    )
     mut_exc_opts.add_argument(
         "-sbml",
         action="store_true",
@@ -388,7 +391,7 @@ def extract_lems_definition_files(path=None):
         try:
             os.makedirs(path)
         except FileExistsError:
-            logger.warn(
+            logger.warning(
                 "{} already exists. Any NeuroML LEMS files in it will be overwritten".format(
                     path
                 )
@@ -612,8 +615,7 @@ def generate_lemsgraph(lems_file_name, verbose_generate=True):
     )
 
 
-def validate_neuroml1(nml1_file_name, verbose_validate=True,
-                      return_string=False):
+def validate_neuroml1(nml1_file_name, verbose_validate=True, return_string=False):
     # type: (str, bool, bool) -> typing.Union[bool, typing.Tuple[bool, str]]
     """Validate a NeuroML v1 file.
 
@@ -632,7 +634,11 @@ def validate_neuroml1(nml1_file_name, verbose_validate=True,
     pre_args = "-validatev1"
     post_args = ""
 
-    warnings.warn("Please note that NeuroMLv1 is deprecated. Functions supporting NeuroMLv1 will be removed in the future.  Please use NeuroMLv2.", FutureWarning, stacklevel=2)
+    warnings.warn(
+        "Please note that NeuroMLv1 is deprecated. Functions supporting NeuroMLv1 will be removed in the future.  Please use NeuroMLv2.",
+        FutureWarning,
+        stacklevel=2,
+    )
 
     return run_jneuroml(
         pre_args,
@@ -806,7 +812,7 @@ def read_neuroml2_file(
                                     getattr(nml2_doc, memb[0]).append(entry)
                     incl_to_remove.append(include)
                 else:
-                    logger.warn("Not including file as it's not valid...")
+                    logger.warning("Not including file as it's not valid...")
 
         for include in incl_to_remove:
             nml2_doc.includes.remove(include)
@@ -858,26 +864,31 @@ def summary(nml2_doc=None, verbose=False):
         """
         Usage:
 
-        pynml-summary <NeuroML file> [-v]
+        pynml-summary <NeuroML file> [-vh]
 
-        Compulsory arguments:
-        NeuroML file: name of file to summarise
+        Required arguments:
+            NeuroML file: name of file to summarise
 
         Optional arguments:
 
-        -v:  enable verbose mode
+            -v/--verbose:  enable verbose mode
+            -h/--help:  print this help text and exit
         """
     )
 
-    if "-v" in sys.argv:
-        verbose = True
-        sys.argv.remove("-v")
-
     if len(sys.argv) < 2:
         print("Argument required.")
         print(usage)
         return
 
+    if "-h" in sys.argv or "--help" in sys.argv:
+        print(usage)
+        return
+
+    if "-v" in sys.argv or "--verbose" in sys.argv:
+        verbose = True
+        sys.argv.remove("-v")
+
     if nml2_doc is None:
         nml2_file_name = sys.argv[1]
         nml2_doc = read_neuroml2_file(nml2_file_name, include_includes=verbose)
@@ -1725,7 +1736,7 @@ def reload_saved_data(
                 events[selections[id]].append(t)
 
             if remove_dat_files_after_load:
-                logger.warn(
+                logger.warning(
                     "Removing file %s after having loading its data!" % file_name
                 )
                 os.remove(file_name)
@@ -1785,7 +1796,7 @@ def reload_saved_data(
                     traces[cols[vi]].append(float(values[vi]))
 
         if remove_dat_files_after_load:
-            logger.warn("Removing file %s after having loading its data!" % file_name)
+            logger.warning("Removing file %s after having loading its data!" % file_name)
             os.remove(file_name)
 
         if plot:
@@ -1793,8 +1804,8 @@ def reload_saved_data(
                 file_name,
                 " (%s)" % simulator if simulator else "",
             )
-            logger.warn("Reloading: %s" % info)
-            fig.canvas.manager.set_window_title(info)
+            logger.warning("Reloading: %s" % info)
+            plt.get_current_fig_manager().set_window_title(info)
 
             legend = False
             for key in cols:
@@ -1888,7 +1899,7 @@ def confirm_neuroml_file(filename):
     # TODO: Ideally we'd like to check the root node: checking file extensions is brittle
     confirm_file_exists(filename)
     if filename.startswith("LEMS_"):
-        logger.warn(
+        logger.warning(
             textwrap.dedent(
                 """
             *************************************************************************************
@@ -1913,7 +1924,7 @@ def confirm_lems_file(filename):
     # TODO: Ideally we'd like to check the root node: checking file extensions is brittle
     confirm_file_exists(filename)
     if filename.endswith("nml"):
-        logger.warn(
+        logger.warning(
             textwrap.dedent(
                 """
             *************************************************************************************
@@ -2039,6 +2050,9 @@ def evaluate_arguments(args):
         elif args.brian2:
             confirm_lems_file(f)
             post_args = "-brian2"
+        elif args.moose:
+            confirm_lems_file(f)
+            post_args = "-moose"
         elif args.sbml:
             confirm_lems_file(f)
             post_args = "-sbml"
@@ -2290,6 +2304,7 @@ def run_jneuroml_with_realtime_output(
     jar_path = get_path_to_jnml_jar()
 
     command = ""
+    command_success = False
 
     try:
         command = 'java -Xmx%s %s -jar  "%s" %s "%s" %s' % (
@@ -2300,7 +2315,7 @@ def run_jneuroml_with_realtime_output(
             target_file,
             post_args,
         )
-        execute_command_in_dir_with_realtime_output(
+        command_success = execute_command_in_dir_with_realtime_output(
             command, exec_in_dir, verbose=verbose, prefix=" jNeuroML >>  "
         )
 
@@ -2313,7 +2328,8 @@ def run_jneuroml_with_realtime_output(
             sys.exit(-1)
         else:
             return False
-    return True
+
+    return command_success
 
 
 def execute_command_in_dir_with_realtime_output(
@@ -2348,19 +2364,20 @@ def execute_command_in_dir_with_realtime_output(
         p = subprocess.Popen(
             shlex.split(command),
             stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
             bufsize=1,
             cwd=directory,
             env=env,
+            universal_newlines=True,
         )
         with p.stdout:
-            for line in iter(p.stdout.readline, b""):
-                logger.debug(line.debug("ascii"))
+            for line in iter(p.stdout.readline, ""):
+                logger.debug(line.strip())
         p.wait()  # wait for the subprocess to exit
     except KeyboardInterrupt as e:
         logger.error("*** Command interrupted: \n       %s" % command)
         if p:
             p.kill()
-        #  return True
         raise e
 
     if not p.returncode == 0:
@@ -2375,7 +2392,7 @@ def execute_command_in_dir_with_realtime_output(
 def execute_command_in_dir(
     command, directory, verbose=DEFAULTS["v"], prefix="Output: ", env=None
 ):
-    # type: (str, str, bool, str, typing.Union[None, str]) -> typing.Tuple(int, str)
+    # type: (str, str, bool, str, typing.Any) -> typing.Tuple[int, str]
     """Execute a command in specific working directory
 
     :param command: command to run
@@ -2422,7 +2439,7 @@ def execute_command_in_dir(
 
     except AttributeError:
         # For python 2.6...
-        logger.warn("Assuming Python 2.6...")
+        logger.warning("Assuming Python 2.6...")
 
         return_string = subprocess.Popen(
             command, cwd=directory, shell=True, stdout=subprocess.PIPE
@@ -2557,7 +2574,7 @@ def generate_plot(
     fig = plt.figure()
     ax = fig.add_subplot(111)
 
-    fig.canvas.manager.set_window_title(title)
+    plt.get_current_fig_manager().set_window_title(title)
     if title_above_plot:
         plt.title(title)
 
@@ -2738,11 +2755,10 @@ def extract_annotations(nml2_file):
 """
 Work in progress: expand a (simple) ComponentType  and evaluate an instance of it by
 giving parameters & required variables
+Used in MOOSE NeuroML reader...
 """
-
-
 def evaluate_component(comp_type, req_variables={}, parameter_values={}):
-    logger.info(
+    logger.debug(
         "Evaluating %s with req:%s; params:%s"
         % (comp_type.name, req_variables, parameter_values)
     )
@@ -2774,8 +2790,8 @@ def evaluate_component(comp_type, req_variables={}, parameter_values={}):
             exec_str += "\n"
 
             exec_str += 'return_vals["%s"] = %s\n' % (cdv.name, cdv.name)
-
-    """logger.info(exec_str)"""
+    exec_str = "from math import exp  # only one required for nml2?\n"+exec_str
+    #logger.info('Exec %s'%exec_str)
     exec(exec_str)
 
     return return_vals
